crikit.measurement.tests package — CRIKit2 0.4.3 documentation

# crikit.measurement.tests package

## Submodules

## crikit.measurement.tests.test_measurement module

crikit.measurement.tests.test_measurement.hsi_dataset()

  Setups and tears down a sample HSI Dataset

crikit.measurement.tests.test_measurement.test_add(hsi_dataset)

  Test peak add

crikit.measurement.tests.test_measurement.test_divide(hsi_dataset)

  Test peak division

crikit.measurement.tests.test_measurement.test_max(hsi_dataset)

  Test peak maximum with f1 < f2 (right)

crikit.measurement.tests.test_measurement.test_max_unordered(hsi_dataset)

  Test peak maximum with f1 > f2 (wrong)

crikit.measurement.tests.test_measurement.test_maxabs(hsi_dataset)

  Test peak maximum abs with f1 < f2 (right)

crikit.measurement.tests.test_measurement.test_min(hsi_dataset)

  Test peak minimum with f1 < f2 (right)

crikit.measurement.tests.test_measurement.test_min_unordered(hsi_dataset)

  Test peak minimum with f1 > f2 (wrong)

crikit.measurement.tests.test_measurement.test_minabs(hsi_dataset)

  Test peak minimum abs with f1 < f2 (right)

crikit.measurement.tests.test_measurement.test_multiply(hsi_dataset)

  Test peak multiplication

crikit.measurement.tests.test_measurement.test_pbt(hsi_dataset)

  Test peak between trough f1 < f2 (right)

crikit.measurement.tests.test_measurement.test_peak(hsi_dataset)

  Test peak amplitude

crikit.measurement.tests.test_measurement.test_subtract(hsi_dataset)

  Test peak subtract

crikit.measurement.tests.test_measurement.test_sum(hsi_dataset)

  Test peak summation f1 < f2 (right)

crikit.measurement.tests.test_measurement.test_sum_re_im(hsi_dataset)

  Test peak summation f1 < f2 (right)

crikit.measurement.tests.test_measurement.test_sum_unordered(hsi_dataset)

  Test peak summation f1 > f2 (wrong)

## crikit.measurement.tests.test_measurements_complex module

crikit.measurement.tests.test_measurements_complex.hsi_dataset()

  Setups and tears down a sample HSI Dataset

crikit.measurement.tests.test_measurements_complex.test_add(hsi_dataset)

  Test peak add

crikit.measurement.tests.test_measurements_complex.test_divide(hsi_dataset)

  Test peak division

crikit.measurement.tests.test_measurements_complex.test_max(hsi_dataset)

  Test peak maximum with f1 < f2 (right)

crikit.measurement.tests.test_measurements_complex.test_max_unordered(hsi_dataset)

  Test peak maximum with f1 > f2 (wrong)

crikit.measurement.tests.test_measurements_complex.test_maxabs(hsi_dataset)

  Test peak maximum abs with f1 < f2 (right)

crikit.measurement.tests.test_measurements_complex.test_min(hsi_dataset)

  Test peak minimum with f1 < f2 (right)

crikit.measurement.tests.test_measurements_complex.test_min_unordered(hsi_dataset)

  Test peak minimum with f1 > f2 (wrong)

crikit.measurement.tests.test_measurements_complex.test_minabs(hsi_dataset)

  Test peak minimum abs with f1 < f2 (right)

crikit.measurement.tests.test_measurements_complex.test_multiply(hsi_dataset)

  Test peak multiplication

crikit.measurement.tests.test_measurements_complex.test_pbt(hsi_dataset)

  Test peak between trough f1 < f2 (right)

crikit.measurement.tests.test_measurements_complex.test_peak(hsi_dataset)

  Test peak amplitude

crikit.measurement.tests.test_measurements_complex.test_subtract(hsi_dataset)

  Test peak subtract

crikit.measurement.tests.test_measurements_complex.test_sum(hsi_dataset)

  Test peak summation f1 < f2 (right)

crikit.measurement.tests.test_measurements_complex.test_sum_abs_re_im(hsi_dataset)

  Test peak summation f1 < f2 (right)

crikit.measurement.tests.test_measurements_complex.test_sum_unordered(hsi_dataset)

  Test peak summation f1 > f2 (wrong)

## crikit.measurement.tests.test_peakfind module

Testing for Hilbert transform method

Using the math relation a^2 / (a^2 + x^2) (Lorentz/Cauchy) has an analytical Hilbert transform: x^2 / (a^2 + x^2)

crikit.measurement.tests.test_peakfind.test_peakfind()

## Module contents